==> libstpk-0.9.11.0.tar.gz: libstpk-0.9.11.0/demo/axis/val_alloc.f90 <==
module val_alloc
! ѿ
! ѿ̾̿̾§
! ¿ -> r,  -> i, ʣǿ -> c
! ʿѾ -> b,  -> p
! ȯŸ -> old, new

  use val_define
  use read_namelist

  implicit none

contains

subroutine val_allocate()

  implicit none

  allocate(r_i(nri))     ! ưºɸ
  allocate(z_i(nzi))     ! ľɸ
  allocate(sst_i(nri))   ! sst ǡ
  allocate(r_u(nr+1))    ! ưºɸ
  allocate(r_s(nr+1))    ! ưºɸ
  allocate(z_w(nz+1))    ! ľɸ
  allocate(z_s(nz+1))    ! ľɸ
  allocate(sst_u(nr+1))  ! sst u
  allocate(sst_s(nr+1))  ! sst s
  allocate(pts(nr+1))    ! ̲
  allocate(qvs(nr+1))    ! ̿
  allocate(ps(nr+1))     ! ̵

!-- 2d val (prognostic value)
  allocate(u_dmp(nr+1,nz+1))   ! ư® dmp
  allocate(v_dmp(nr+1,nz+1))   ! ® dmp
  allocate(w_dmp(nr+1,nz+1))   ! ľ® dmp
  allocate(p_dmp(nr+1,nz+1))   ! ʲ dmp
  allocate(t_dmp(nr+1,nz+1))   !  dmp
  allocate(qv_dmp(nr+1,nz+1))  !  dmp
  allocate(qt_dmp(nr+1,nz+1))  ! ŷ dmp
  allocate(u_old(nr+1,nz+1))   ! ư® old
  allocate(v_old(nr+1,nz+1))   ! ® old
  allocate(w_old(nr+1,nz+1))   ! ľ® old
  allocate(p_old(nr+1,nz+1))   ! ʲ old
  allocate(t_old(nr+1,nz+1))   !  old
  allocate(qv_old(nr+1,nz+1))  !  old
  allocate(qt_old(nr+1,nz+1))  ! ŷ old
  allocate(u_new(nr+1,nz+1))   ! ư® new
  allocate(v_new(nr+1,nz+1))   ! ® new
  allocate(w_new(nr+1,nz+1))   ! ľ® new
  allocate(p_new(nr+1,nz+1))   ! ʲ new
  allocate(t_new(nr+1,nz+1))   !  new
  allocate(qv_new(nr+1,nz+1))  !  new
  allocate(qt_new(nr+1,nz+1))  ! ŷ new
  allocate(u_tmp(nr+1,nz+1))   ! ư® tmp
  allocate(v_tmp(nr+1,nz+1))   ! ® tmp
  allocate(w_tmp(nr+1,nz+1))   ! ľ® tmp
  allocate(p_tmp(nr+1,nz+1))   ! ʲ tmp
  allocate(t_tmp(nr+1,nz+1))   !  tmp
  allocate(qv_tmp(nr+1,nz+1))  !  tmp
  allocate(qt_tmp(nr+1,nz+1))  ! ŷ tmp

!-- 2d val (working value)
  allocate(u_u(nr+1,nz+1))   ! ư® u
  allocate(v_u(nr+1,nz+1))   ! ® u
  allocate(w_u(nr+1,nz+1))   ! ľ® u
  allocate(p_u(nr+1,nz+1))   ! ʲ u
  allocate(t_u(nr+1,nz+1))   !  u
  allocate(qv_u(nr+1,nz+1))  !  u
  allocate(qt_u(nr+1,nz+1))  ! ŷ u
  allocate(u_s(nr+1,nz+1))   ! ư® s
  allocate(v_s(nr+1,nz+1))   ! ® s
  allocate(w_s(nr+1,nz+1))   ! ľ® s
  allocate(p_s(nr+1,nz+1))   ! ʲ s
  allocate(t_s(nr+1,nz+1))   !  s
  allocate(qv_s(nr+1,nz+1))  !  s
  allocate(qt_s(nr+1,nz+1))  ! ŷ s
  allocate(u_w(nr+1,nz+1))   ! ư® w
  allocate(v_w(nr+1,nz+1))   ! ® w
  allocate(w_w(nr+1,nz+1))   ! ľ® w
  allocate(p_w(nr+1,nz+1))   ! ʲ w
  allocate(t_w(nr+1,nz+1))   !  w
  allocate(qv_w(nr+1,nz+1))  !  w
  allocate(qt_w(nr+1,nz+1))  ! ŷ w

!-- 2d val (diagnostic value)
  allocate(ub_u(nr+1,nz+1))     ! ư½® u
  allocate(vb_s(nr+1,nz+1))     ! ® s
  allocate(wb_w(nr+1,nz+1))     ! ľ® w
  allocate(pb_s(nr+1,nz+1))     ! Ͻ s
  allocate(ptb_u(nr+1,nz+1))    ! ̽ u
  allocate(ptb_s(nr+1,nz+1))    ! ̽ s
  allocate(ptb_w(nr+1,nz+1))    ! ̽ w
  allocate(qvb_u(nr+1,nz+1))    !  u
  allocate(qvb_s(nr+1,nz+1))    !  s
  allocate(qvb_w(nr+1,nz+1))    !  w
  allocate(qtb_s(nr+1,nz+1))    ! ŷ庮 s
  allocate(ptv_u(nr+1,nz+1))    !  u
  allocate(ptv_s(nr+1,nz+1))    !  s
  allocate(ptv_w(nr+1,nz+1))    !  w
  allocate(ptvb_s(nr+1,nz+1))   !  s
  allocate(ptvb_u(nr+1,nz+1))   !  u
  allocate(ptvb_w(nr+1,nz+1))   !  w
  allocate(pte_u(nr+1,nz+1))    !  u
  allocate(pte_s(nr+1,nz+1))    !  s
  allocate(pteb_s(nr+1,nz+1))   ! 
  allocate(rhob_u(nr+1,nz+1))   ! ̩ u
  allocate(rhob_s(nr+1,nz+1))   ! ̩ s
  allocate(rhob_w(nr+1,nz+1))   ! ̩ w
  allocate(temp_u(nr+1,nz+1))   !  u
  allocate(temp_s(nr+1,nz+1))   !  s
  allocate(temp_w(nr+1,nz+1))   !  w
  allocate(tempb_s(nr+1,nz+1))  ! 
  allocate(u_i(nri,nzi))        ! ư½®ٽǡ
  allocate(v_i(nri,nzi))        ! ®ٽǡ
  allocate(w_i(nri,nzi))        ! ľ®ٽǡ
  allocate(p_i(nri,nzi))        ! Ͻǡ
  allocate(t_i(nri,nzi))        ! ̽ǡ
  allocate(qv_i(nri,nzi))       ! ǡ
  allocate(qt_i(nri,nzi))       ! ŷʪǡ

!-- 2d val (force term)
  allocate(force_u(nr+1,nz+1))   ! u forcing term
  allocate(force_v(nr+1,nz+1))   ! v forcing term
  allocate(force_w(nr+1,nz+1))   ! w forcing term
  allocate(force_p(nr+1,nz+1))   ! p forcing term
  allocate(force_t(nr+1,nz+1))   ! t forcing term
  allocate(force_qv(nr+1,nz+1))  ! qv forcing term
  allocate(force_qt(nr+1,nz+1))  ! qt forcing term
  allocate(forcea_u(nr+1,nz+1))  ! u forcing term
  allocate(forcea_v(nr+1,nz+1))  ! v forcing term
  allocate(forcea_w(nr+1,nz+1))  ! w forcing term
  allocate(forcea_p(nr+1,nz+1))  ! p forcing term
  allocate(forcea_t(nr+1,nz+1))  ! t forcing term
  allocate(forcea_qv(nr+1,nz+1)) ! qv forcing term
  allocate(forcea_qt(nr+1,nz+1)) ! qt forcing term
  allocate(ADV_u(nr+1,nz+1))     ! ADV u
  allocate(ADV_v(nr+1,nz+1))     ! ADV v
  allocate(ADV_w(nr+1,nz+1))     ! ADV w
  allocate(ADV_t(nr+1,nz+1))     ! ADV t
  allocate(ADV_qv(nr+1,nz+1))    ! ADV qv
  allocate(ADV_qt(nr+1,nz+1))    ! ADV qt
  allocate(DIFF_u(nr+1,nz+1))    ! DIFF u
  allocate(DIFF_v(nr+1,nz+1))    ! DIFF v
  allocate(DIFF_w(nr+1,nz+1))    ! DIFF w
  allocate(DIFF_t(nr+1,nz+1))    ! DIFF t
  allocate(DIFF_qv(nr+1,nz+1))   ! DIFF qv
  allocate(DIFF_qt(nr+1,nz+1))   ! DIFF qt
  allocate(GRADP_u(nr+1,nz+1))   ! GRADP u
  allocate(GRADP_w(nr+1,nz+1))   ! GRADP w
  allocate(FLUX_s(nr+1,nz+1))    ! FLUX s
  allocate(SPG_u(nr+1,nz+1))     ! sponge u
  allocate(SPG_v(nr+1,nz+1))     ! sponge v
  allocate(SPG_w(nr+1,nz+1))     ! sponge w
  allocate(SPG_t(nr+1,nz+1))     ! sponge t
  allocate(SPG_qv(nr+1,nz+1))    ! sponge qv
  allocate(SPG_qt(nr+1,nz+1))    ! sponge qt
  allocate(FALL_qt(nr+1,nz+1))   ! falling qt
  allocate(RAD_t(nr+1,nz+1))     ! radiation t
  allocate(BUOY_w(nr+1,nz+1))    ! Buoyancy w
  allocate(CC_u(nr+1,nz+1))      ! Cori + Centri u
  allocate(CC_v(nr+1,nz+1))      ! Cori + Centri v

end subroutine

end module

==> libstpk-0.9.16.0.tar.gz: libstpk-0.9.16.0/demo/axis/val_alloc.f90 <==
module val_alloc
! ѿ
! ѿ̾̿̾§
! ¿ -> r,  -> i, ʣǿ -> c
! ʿѾ -> b,  -> p
! ȯŸ -> old, new

  use val_define
  use read_namelist

  implicit none

contains

subroutine val_allocate()

  implicit none

  allocate(r_i(nri))     ! ưºɸ
  allocate(z_i(nzi))     ! ľɸ
  allocate(sst_i(nri))   ! sst ǡ
  allocate(r_u(nr+1))    ! ưºɸ
  allocate(r_s(nr+1))    ! ưºɸ
  allocate(z_w(nz+1))    ! ľɸ
  allocate(z_s(nz+1))    ! ľɸ
  allocate(sst_u(nr+1))  ! sst u
  allocate(sst_s(nr+1))  ! sst s
  allocate(pts(nr+1))    ! ̲
  allocate(qvs(nr+1))    ! ̿
  allocate(ps(nr+1))     ! ̵
  allocate(us_dmp(nr+1))   ! surface ư® dmp
  allocate(vs_dmp(nr+1))   ! surface ® dmp
  allocate(ws_dmp(nr+1))   ! surface ľ® dmp
  allocate(ps_dmp(nr+1))   ! surface  dmp
  allocate(ts_dmp(nr+1))   ! surface  dmp
  allocate(qvs_dmp(nr+1))  ! surface  dmp
  allocate(qts_dmp(nr+1))  ! surface ŷ dmp
  allocate(Tsurf(nr+1))    ! surface temp.

!-- 2d val (prognostic value)
  allocate(u_dmp(nr+1,nz+1))   ! ư® dmp
  allocate(v_dmp(nr+1,nz+1))   ! ® dmp
  allocate(w_dmp(nr+1,nz+1))   ! ľ® dmp
  allocate(p_dmp(nr+1,nz+1))   !  dmp
  allocate(t_dmp(nr+1,nz+1))   !  dmp
  allocate(qv_dmp(nr+1,nz+1))  !  dmp
  allocate(qc_dmp(nr+1,nz+1))  ! ŷ dmp
  allocate(ql_dmp(nr+1,nz+1))  ! ŷ dmp
  allocate(u_old(nr+1,nz+1))   ! ư® old
  allocate(v_old(nr+1,nz+1))   ! ® old
  allocate(w_old(nr+1,nz+1))   ! ľ® old
  allocate(p_old(nr+1,nz+1))   ! ʲ old
  allocate(t_old(nr+1,nz+1))   !  old
  allocate(qv_old(nr+1,nz+1))  !  old
  allocate(qc_old(nr+1,nz+1))  ! ŷ old
  allocate(ql_old(nr+1,nz+1))  ! ŷ old
  allocate(u_new(nr+1,nz+1))   ! ư® new
  allocate(v_new(nr+1,nz+1))   ! ® new
  allocate(w_new(nr+1,nz+1))   ! ľ® new
  allocate(p_new(nr+1,nz+1))   ! ʲ new
  allocate(t_new(nr+1,nz+1))   !  new
  allocate(qv_new(nr+1,nz+1))  !  new
  allocate(qc_new(nr+1,nz+1))  ! ŷ new
  allocate(ql_new(nr+1,nz+1))  ! ŷ new
  allocate(u_tmp(nr+1,nz+1))   ! ư® tmp
  allocate(v_tmp(nr+1,nz+1))   ! ® tmp
  allocate(w_tmp(nr+1,nz+1))   ! ľ® tmp
  allocate(p_tmp(nr+1,nz+1))   ! ʲ tmp
  allocate(t_tmp(nr+1,nz+1))   !  tmp
  allocate(qv_tmp(nr+1,nz+1))  !  tmp
  allocate(qc_tmp(nr+1,nz+1))  ! ŷ tmp
  allocate(ql_tmp(nr+1,nz+1))  ! ŷ tmp

!-- 2d val (working value)
  allocate(u_u(nr+1,nz+1))   ! ư® u
  allocate(v_u(nr+1,nz+1))   ! ® u
  allocate(w_u(nr+1,nz+1))   ! ľ® u
  allocate(p_u(nr+1,nz+1))   ! ʲ u
  allocate(t_u(nr+1,nz+1))   !  u
  allocate(qv_u(nr+1,nz+1))  !  u
  allocate(qc_u(nr+1,nz+1))  ! ŷ u
  allocate(ql_u(nr+1,nz+1))  ! ŷ u
  allocate(u_s(nr+1,nz+1))   ! ư® s
  allocate(v_s(nr+1,nz+1))   ! ® s
  allocate(w_s(nr+1,nz+1))   ! ľ® s
  allocate(p_s(nr+1,nz+1))   ! ʲ s
  allocate(t_s(nr+1,nz+1))   !  s
  allocate(qv_s(nr+1,nz+1))  !  s
  allocate(qc_s(nr+1,nz+1))  ! ŷ s
  allocate(ql_s(nr+1,nz+1))  ! ŷ s
  allocate(u_w(nr+1,nz+1))   ! ư® w
  allocate(v_w(nr+1,nz+1))   ! ® w
  allocate(w_w(nr+1,nz+1))   ! ľ® w
  allocate(p_w(nr+1,nz+1))   ! ʲ w
  allocate(t_w(nr+1,nz+1))   !  w
  allocate(qv_w(nr+1,nz+1))  !  w
  allocate(qc_w(nr+1,nz+1))  ! ŷ w
  allocate(ql_w(nr+1,nz+1))  ! ŷ w
  allocate(u_c(nr+1,nz+1))   ! ư® c
  allocate(v_c(nr+1,nz+1))   ! ® c
  allocate(w_c(nr+1,nz+1))   ! ľ® c
  allocate(p_c(nr+1,nz+1))   ! ʲ c
  allocate(t_c(nr+1,nz+1))   !  c
  allocate(qv_c(nr+1,nz+1))  !  c
  allocate(qc_c(nr+1,nz+1))  ! ŷ c
  allocate(ql_c(nr+1,nz+1))  ! ŷ c

!-- 2d val (diagnostic value)
  allocate(ub_u(nr+1,nz+1))     ! ư½® u
  allocate(vb_s(nr+1,nz+1))     ! ® s
  allocate(wb_w(nr+1,nz+1))     ! ľ® w
  allocate(pb_s(nr+1,nz+1))     ! Ͻ s
  allocate(ptb_u(nr+1,nz+1))    ! ̽ u
  allocate(ptb_s(nr+1,nz+1))    ! ̽ s
  allocate(ptb_w(nr+1,nz+1))    ! ̽ w
  allocate(pti_u(nr+1,nz+1))    ! ̽ u for BUOY
  allocate(pti_s(nr+1,nz+1))    ! ̽ s for BUOY
  allocate(pti_w(nr+1,nz+1))    ! ̽ w for BUOY
  allocate(qvb_u(nr+1,nz+1))    !  u
  allocate(qvb_s(nr+1,nz+1))    !  s
  allocate(qvb_w(nr+1,nz+1))    !  w
  allocate(qtb_s(nr+1,nz+1))    ! ŷ庮 s
  allocate(ptv_u(nr+1,nz+1))    !  u
  allocate(ptv_s(nr+1,nz+1))    !  s
  allocate(ptv_w(nr+1,nz+1))    !  w
  allocate(ptv_c(nr+1,nz+1))    !  c
  allocate(ptvb_s(nr+1,nz+1))   !  s
  allocate(ptvb_u(nr+1,nz+1))   !  u
  allocate(ptvb_w(nr+1,nz+1))   !  w
  allocate(pte_u(nr+1,nz+1))    !  u
  allocate(pte_s(nr+1,nz+1))    !  s
  allocate(pte_w(nr+1,nz+1))    !  w
  allocate(pte_c(nr+1,nz+1))    !  c
  allocate(rhob_u(nr+1,nz+1))   ! ̩ u
  allocate(rhob_s(nr+1,nz+1))   ! ̩ s
  allocate(rhob_w(nr+1,nz+1))   ! ̩ w
  allocate(temp_u(nr+1,nz+1))   !  u
  allocate(temp_s(nr+1,nz+1))   !  s
  allocate(temp_w(nr+1,nz+1))   !  w
  allocate(temp_c(nr+1,nz+1))   !  c
  allocate(tempb_s(nr+1,nz+1))  ! 
  allocate(tempb_w(nr+1,nz+1))  ! 
  allocate(u_i(nri,nzi))        ! ư½®ٽǡ
  allocate(v_i(nri,nzi))        ! ®ٽǡ
  allocate(w_i(nri,nzi))        ! ľ®ٽǡ
  allocate(p_i(nri,nzi))        ! Ͻǡ
  allocate(t_i(nri,nzi))        ! ̽ǡ
  allocate(qv_i(nri,nzi))       ! ǡ
  allocate(qc_i(nri,nzi))       ! ŷʪǡ
  allocate(ql_i(nri,nzi))       ! ŷʪǡ

!-- 2d val (force term)
  allocate(force_u(nr+1,nz+1))   ! u forcing term
  allocate(force_v(nr+1,nz+1))   ! v forcing term
  allocate(force_w(nr+1,nz+1))   ! w forcing term
  allocate(force_p(nr+1,nz+1))   ! p forcing term
  allocate(force_t(nr+1,nz+1))   ! t forcing term
  allocate(force_qv(nr+1,nz+1))  ! qv forcing term
  allocate(force_qc(nr+1,nz+1))  ! qt forcing term
  allocate(force_ql(nr+1,nz+1))  ! qt forcing term
  allocate(forcea_u(nr+1,nz+1))  ! u forcing term
  allocate(forcea_v(nr+1,nz+1))  ! v forcing term
  allocate(forcea_w(nr+1,nz+1))  ! w forcing term
  allocate(forcea_p(nr+1,nz+1))  ! p forcing term
  allocate(forcea_t(nr+1,nz+1))  ! t forcing term
  allocate(forcea_qv(nr+1,nz+1)) ! qv forcing term
  allocate(forcea_qc(nr+1,nz+1)) ! qt forcing term
  allocate(forcea_ql(nr+1,nz+1)) ! qt forcing term
  allocate(ADV_u(nr+1,nz+1))     ! ADV u
  allocate(ADV_v(nr+1,nz+1))     ! ADV v
  allocate(ADV_w(nr+1,nz+1))     ! ADV w
  allocate(ADV_t(nr+1,nz+1))     ! ADV t
  allocate(ADV_qv(nr+1,nz+1))    ! ADV qv
  allocate(ADV_qc(nr+1,nz+1))    ! ADV qt
  allocate(ADV_ql(nr+1,nz+1))    ! ADV qt
  allocate(DIFF_u(nr+1,nz+1))    ! DIFF u
  allocate(DIFF_v(nr+1,nz+1))    ! DIFF v
  allocate(DIFF_w(nr+1,nz+1))    ! DIFF w
  allocate(DIFF_t(nr+1,nz+1))    ! DIFF t
  allocate(DIFF_qv(nr+1,nz+1))   ! DIFF qv
  allocate(DIFF_qc(nr+1,nz+1))   ! DIFF qt
  allocate(DIFF_ql(nr+1,nz+1))   ! DIFF qt
  allocate(NUMD_u(nr+1,nz+1))    ! NUMDIFF u
  allocate(NUMD_v(nr+1,nz+1))    ! NUMDIFF v
  allocate(NUMD_w(nr+1,nz+1))    ! NUMDIFF w
  allocate(NUMD_t(nr+1,nz+1))    ! NUMDIFF t
  allocate(NUMD_qv(nr+1,nz+1))   ! NUMDIFF qv
  allocate(NUMD_qc(nr+1,nz+1))   ! NUMDIFF qc
  allocate(NUMD_ql(nr+1,nz+1))   ! NUMDIFF ql
  allocate(GRADP_u(nr+1,nz+1))   ! GRADP u
  allocate(GRADP_w(nr+1,nz+1))   ! GRADP w
  allocate(FLUX_s(nr+1,nz+1))    ! FLUX s
  allocate(SPG_u(nr+1,nz+1))     ! sponge u
  allocate(SPG_v(nr+1,nz+1))     ! sponge v
  allocate(SPG_w(nr+1,nz+1))     ! sponge w
  allocate(SPG_t(nr+1,nz+1))     ! sponge t
  allocate(SPG_qv(nr+1,nz+1))    ! sponge qv
  allocate(SPG_qc(nr+1,nz+1))    ! sponge qt
  allocate(SPG_ql(nr+1,nz+1))    ! sponge qt
  allocate(RAD_t(nr+1,nz+1))     ! radiation t
  allocate(BUOY_w(nr+1,nz+1))    ! Buoyancy w
  allocate(CLOUD_pt(nr+1,nz+1))  ! Cloud physics pt
  allocate(CLOUD_qv(nr+1,nz+1))  ! Cloud physics qv
  allocate(CLOUD_qc(nr+1,nz+1))  ! Cloud physics qc
  allocate(CLOUD_ql(nr+1,nz+1))  ! Cloud physics ql
  allocate(CC_u(nr+1,nz+1))      ! Cori + Centri u
  allocate(CC_v(nr+1,nz+1))      ! Cori + Centri v

end subroutine

end module
